# jottalib authors and community #

##Code 

  - Håvard Gulldahl - *current maintainer*
  - Alexander Krivács Schrøder - *patches*


##Community contributions

  - Joel Kåberg - *debugging and reverse engineering protocol*




[See all Github contributors](https://github.com/havardgulldahl/jottalib/contributors)
